@@ -22,6 +22,7 @@ import tempfile
 import datetime
 import pkgutil
 import warnings
+from xml.sax import saxutils
 
 import numpy as np
 from numpy import nanmedian
@@ -718,16 +719,14 @@ class Nansat(Domain, Exporter):
         """
         Create numpy array with watermask (water=1, land=0)
 
-        TODO: cross-check and update docstring and references/links
-
         250 meters resolution watermask from MODIS 44W Product:
         http://www.glcf.umd.edu/data/watermask/
 
         Watermask is stored as tiles in TIF(LZW) format and a VRT file
         All files are stored in one directory.
         A tarball with compressed TIF and VRT files should be additionally
-        downloaded from the Nansat wiki:
-        https://svn.nersc.no/nansat/wiki/Nansat/Data/Watermask
+        downloaded from the Nansat documentation page:
+        http://nansat.readthedocs.io/en/latest/source/features.html#differentiating-between-land-and-water
 
         The method :
             Gets the directory either from input parameter or from environment
@@ -739,7 +738,7 @@ class Nansat(Domain, Exporter):
 
         Parameters
         -----------
-        mod44path : string, optional, default=None
+        mod44path : string
             path with MOD44W Products and a VRT file
         dst_domain : Domain
             destination domain other than self
@@ -757,6 +756,7 @@ class Nansat(Domain, Exporter):
         See Also
         ---------
         http://www.glcf.umd.edu/data/watermask/
+        http://nansat.readthedocs.io/en/latest/source/features.html#differentiating-between-land-and-water
 
         """
         if dstDomain is not None:
@@ -1033,23 +1033,28 @@ class Nansat(Domain, Exporter):
     def time_coverage_end(self):
         return parse_time(self.get_metadata('time_coverage_end'))
 
-    def get_metadata(self, key=None, band_id=None, bandID=None):
+    def get_metadata(self, key=None, band_id=None, bandID=None, unescape=True):
         """Get metadata from self.vrt.dataset
 
         Parameters
         ----------
-        key : string, optional
+        key : str
             name of the metadata key. If not givem all metadata is returned
-        band_id : int or str, optional
+        band_id : int or str
             number or name of band to get metadata from.
             If not given, global metadata is returned
+        unescape : bool
+            Replace '&quot;', '&amp;', '&lt;' and '&gt;' with these symbols " & < > ?
 
         Returns
         --------
         * string with metadata if key is given and found
-        * empty string if key is given and not found
         * dictionary with all metadata if key is not given
 
+        Raises
+        ------
+        ValueError, if key is not found
+
         """
         if bandID is not None:
             warnings.warn(self.INIT_BANDID_WARNING, NansatFutureWarning)
@@ -1061,6 +1066,11 @@ class Nansat(Domain, Exporter):
         else:
             metadata = self.get_GDALRasterBand(band_id).GetMetadata()
 
+        # remove escapes of special characters
+        if unescape:
+            for i in metadata:
+                metadata[i] = saxutils.unescape(metadata[i], {'&quot;': '"'})
+
         # get all metadata or from a key
         if key is not None:
             try:
