@@ -24,6 +24,7 @@ import gdal
 import pythesint as pti
 
 from nansat.node import Node
+from nansat.nsr import NSR
 from nansat.vrt import VRT
 from nansat.tests.nansat_test_base import NansatTestBase
 
@@ -337,17 +338,26 @@ class VRTTest(NansatTestBase):
         self.assertEqual(vrt._create_band_name({'name': 'name1'}), ('name1', {}))
 
     def test_create_band_name_wkv(self):
+        short_name='sigma0'
+        wkv = dict(short_name=short_name)
+        self.mock_pti['get_wkv_variable'].return_value=wkv
+        vrt = VRT()
+        self.assertEqual(vrt._create_band_name({'wkv': short_name}), (short_name, wkv))
+        self.assertEqual(vrt._create_band_name({'wkv': short_name, 'suffix': 'HH'}),
+                         (short_name + '_HH', wkv))
+
+    def test_create_band_name_existing_name(self):
+        self.mock_pti['get_wkv_variable'].side_effect = IndexError
+        vrt = VRT.from_array(np.zeros((10,10)))
+        vrt.dataset.GetRasterBand(1).SetMetadata({'name':'band1'})
+        self.assertEqual(vrt._create_band_name({'name': 'band1'}), ('band1_0000', {}))
+
+    def test_create_band_name_wkv_and_name(self):
+        name = 'some_name'
         wkv = dict(short_name='sigma0')
         self.mock_pti['get_wkv_variable'].return_value=wkv
         vrt = VRT()
-        self.assertEqual(vrt._create_band_name({'wkv': 'sigma0'}), ('sigma0', wkv))
-        self.assertEqual(vrt._create_band_name({'wkv': 'sigma0', 'suffix': 'HH'}),
-                         ('sigma0_HH', wkv))
-
-    def test_create_band_name_existing_name(self):
-        vrt = VRT.from_array(np.zeros((10,10)))
-        vrt.dataset.GetRasterBand(1).SetMetadata({'name':'band1'})
-        self.assertEqual(vrt._create_band_name({'name': 'band1'}), ('band1_000', {}))
+        self.assertEqual(vrt._create_band_name({'wkv': 'sigma0', 'name': name}), (name, wkv))
 
     def test_leave_few_bands(self):
         ds = gdal.Open(self.test_file_gcps)
@@ -560,5 +570,48 @@ class VRTTest(NansatTestBase):
             self.assertEqual(w[0].category, NansatFutureWarning)
         self.assertTrue(mock_VRT.create_bands.called_once)
 
+    def test_transform_coordinates_list(self):
+        src_srs = NSR()
+        dst_srs = NSR(str('+proj=stere'))
+        src_points = ([1,2,3,4],[5,6,7,8])
+        dst_x, dst_y, dst_z = VRT.transform_coordinates(src_srs, src_points, dst_srs)
+        # check if shape of the result matches the expected shape (list with four points)
+        self.assertEqual(dst_x.shape, (4,))
+        self.assertEqual(dst_y.shape, (4,))
+        self.assertEqual(dst_z.shape, (4,))
+
+    def test_transform_coordinates_1d_array(self):
+        src_srs = NSR()
+        dst_srs = NSR(str('+proj=stere'))
+        src_points = (np.array([1,2,3,4]), np.array([5,6,7,8]), np.array([5,6,7,8]))
+        dst_x, dst_y, dst_z = VRT.transform_coordinates(src_srs, src_points, dst_srs)
+        # check if shape of the result matches the expected shape (list with four points)
+        self.assertEqual(dst_x.shape, (4,))
+        self.assertEqual(dst_y.shape, (4,))
+        self.assertEqual(dst_z.shape, (4,))
+
+    def test_transform_coordinates_2d_array(self):
+        src_srs = NSR()
+        dst_srs = NSR(str('+proj=stere'))
+        src_points = (np.array([[1,2,3,4],[1,2,3,4]]),
+                      np.array([[5,6,7,8],[5,6,7,8]]),
+                      np.array([[5,6,7,8],[5,6,7,8]]),)
+        dst_x, dst_y, dst_z = VRT.transform_coordinates(src_srs, src_points, dst_srs)
+        # check if shape of the result matches the expected shape (2x4 array)
+        self.assertEqual(dst_x.shape, (2,4))
+        self.assertEqual(dst_y.shape, (2,4))
+        self.assertEqual(dst_z.shape, (2,4))
+
+    def test_reproject_gcps(self):
+        lon, lat = np.meshgrid(np.linspace(0, 5, 10), np.linspace(10, 20, 30))
+        vrt1 = VRT.from_lonlat(lon, lat)
+        vrt1.reproject_GCPs(str('+proj=stere'))
+        self.assertIn('Stereographic', vrt1.dataset.GetGCPProjection())
+        self.assertEqual(vrt1.dataset.GetGCPs()[0].GCPX, 0)
+        self.assertEqual(vrt1.dataset.GetGCPs()[0].GCPY, 2217341.7476875726)
+        self.assertEqual(vrt1.dataset.GetGCPs()[-1].GCPX, 1082008.9593705384)
+        self.assertEqual(vrt1.dataset.GetGCPs()[-1].GCPY, 4320951.334629638)
+
+
 if __name__ == "__main__":
     unittest.main()
