@@ -696,30 +696,35 @@ class VRT(object):
 
     def _create_band_name(self, dst):
         """Create band name based on destination band dictionary <dst>"""
-        wkv = {}
         band_name = dst.get('name', None)
 
+        # try to get metadata from WKV using PyThesInt if it exists
+        wkv_dst = dst.get('wkv', None)
+        try:
+            wkv_pti = pti.get_wkv_variable(str(wkv_dst))
+        except IndexError:
+            # IndexError is raised when PyThesInt doesn't find the requested WKV.
+            # In that case and empty dict without any metadata is created
+            wkv = {}
+        else:
+            # If WKV was found by PyThesInt, a dict with metadata is created
+            wkv = dict(wkv_pti)
+
         if band_name is None:
-            try:
-                # get metadata from WKV using PyThesInt
-                wkv = pti.get_wkv_variable(dst.get('wkv', ''))
-            except IndexError:
-                band_name = 'band'
-            else:
-                band_name = wkv['short_name']
-                if 'suffix' in dst:
-                     band_name += '_' + dst['suffix']
+            band_name = wkv.get('short_name', 'band')
+            if 'suffix' in dst:
+                 band_name += '_' + dst['suffix']
 
         # create list of available bands (to prevent duplicate names)
         band_names = [self.dataset.GetRasterBand(i + 1).GetMetadataItem(str('name'))
                         for i in range(self.dataset.RasterCount)]
 
-        # check if name already exist and add '_NNN'
+        # check if name already exist and add '_NNNN'
         dst_band_name = band_name
-        for n in range(999):
+        for n in range(9999):
             if dst_band_name not in band_names:
                 break
-            dst_band_name = '%s_%03d' % (band_name, n)
+            dst_band_name = '%s_%04d' % (band_name, n)
 
         return dst_band_name, wkv
 
@@ -1454,7 +1459,7 @@ class VRT(object):
 
     def transform_points(self, col_vector, row_vector, dst2src=0,
                          dst_srs=NSR(), dst_ds=None, options=None):
-        """Transform given lists of X,Y coordinates into lat/lon
+        """Transform input pixel/line coordinates into lon/lat (or opposite)
 
         Parameters
         -----------
@@ -1580,23 +1585,51 @@ class VRT(object):
         --------
         Reprojects all GCPs to new SRS and updates GCPProjection
         """
-        # Make tranformer from GCP SRS to destination SRS
+        # transform coordinates of original GCPs
         dst_srs = NSR(dst_srs)
         src_srs = NSR(self.dataset.GetGCPProjection())
-        transformer = osr.CoordinateTransformation(src_srs, dst_srs)
-
-        # Reproject all GCPs
+        # make three tuples with X, Y and Z values of GCPs
+        src_points = list(zip(*[(gcp.GCPX, gcp.GCPY, gcp.GCPZ) for gcp in self.dataset.GetGCPs()]))
+        dst_points = VRT.transform_coordinates(src_srs, src_points, dst_srs)
+        # create new GCPs
         dst_gcps = []
-        for src_gcp in self.dataset.GetGCPs():
-            (x, y, z) = transformer.TransformPoint(src_gcp.GCPX,
-                                                   src_gcp.GCPY,
-                                                   src_gcp.GCPZ)
-            dstGCP = gdal.GCP(x, y, z, src_gcp.GCPPixel,
-                              src_gcp.GCPLine, src_gcp.Info, src_gcp.Id)
-            dst_gcps.append(dstGCP)
-
+        for p in zip(self.dataset.GetGCPs(), *dst_points):
+            dst_gcp = gdal.GCP(p[1], p[2], p[3],
+                               p[0].GCPPixel,  p[0].GCPLine, p[0].Info, p[0].Id)
+            dst_gcps.append(dst_gcp)
         # Update dataset
         self.dataset.SetGCPs(dst_gcps, dst_srs.wkt)
+        self.dataset.FlushCache()
+
+    @staticmethod
+    def transform_coordinates(src_srs, src_points, dst_srs):
+        """ Transform coordinates of points from one spatial reference to another
+
+        Parameters
+        ----------
+        src_srs : nansat.NSR
+            Source spatial reference system
+        src_points : tuple of two or three N-D arrays
+            Coordinates of points in the source spatial reference system. A tuple with (X, Y) or
+            (X, Y, Z) coordinates arrays. Each coordinate Each array can be a list, 1D, 2D, N-D
+            array.
+        dst_srs : nansat.NSR
+            Destination spatial reference
+
+        Returns
+        -------
+        dst_points : tuple of two or three N-D arrays
+            Coordinates of points in the destination spatial reference system. A tuple with (X, Y) or
+            (X, Y, Z) coordinates arrays. Each coordinate Each array can be 1D, 2D, N-D
+            array. Shape of output arrays corrrrespond to shape of inputs.
+
+        """
+        transformer = osr.CoordinateTransformation(src_srs, dst_srs)
+        src_shape = np.array(src_points[0]).shape
+        src_points = list(zip(*[np.array(xyz).flatten() for xyz in src_points]))
+        dst_points = transformer.TransformPoints(src_points)
+        dst_x, dst_y, dst_z = np.array(list(zip(*dst_points)))
+        return dst_x.reshape(src_shape), dst_y.reshape(src_shape), dst_z.reshape(src_shape)
 
     def set_offset_size(self, axis, offset, size):
         """Set offset and  size in VRT dataset and band attributes"""
